<?php

namespace App\Provider\Dummy;

use App\Model\Stop;
use App\Provider\Database\GenericStopRepository;
use App\Provider\StopRepository;
use App\Service\Proxy\ReferenceFactory;
use Tightenco\Collect\Support\Collection;
use Kadet\Functional as f;
use Kadet\Functional\Predicates as p;

class DummyStopRepository implements StopRepository
{
    private $reference;
    private $all;

    /**
     * DummyDepartureProviderRepository constructor.
     *
     * @param $reference
     */
    public function __construct(ReferenceFactory $reference)
    {
        $this->reference = $reference;

        $this->all = collect([
            Stop::createFromArray(['id' => 1, 'name' => 'Lipowa', 'variant' => '01', 'onDemand' => true, 'latitude' => 0, 'longitude' => 0 ]),
            Stop::createFromArray(['id' => 2, 'name' => 'Bukowa', 'variant' => '01', 'onDemand' => false ]),
            Stop::createFromArray(['id' => 3, 'name' => 'Kasztanowa', 'variant' => '01', 'onDemand' => false ]),
            Stop::createFromArray(['id' => 4, 'name' => 'Brzozowa', 'variant' => '01', 'onDemand' => false ]),
            Stop::createFromArray(['id' => 5, 'name' => 'Brzozowa', 'variant' => '02', 'onDemand' => false ]),
        ]);
    }

    public function getAll(): Collection
    {
        return collect($this->all);
    }

    public function getAllGroups(): Collection
    {
        return GenericStopRepository::group($this->getAll());
    }

    public function getById($id): ?Stop
    {
        return $this->all->first(p\property('id', p\equals($id)));
    }

    public function getManyById($ids): Collection
    {
        return $this->all->filter(p\property('id', function ($id) use ($ids) {
            return in_array($id, $ids);
        }));
    }

    public function findGroupsByName(string $name): Collection
    {
        return GenericStopRepository::group($this->all->filter(p\property('name', function ($stopName) use ($name) {
            return stripos($stopName, $name) !== false;
        })));
    }
}